==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/page/scrolling/ScrollingTreeScrollingNodeDelegate.cpp <==
/*
 * Copyright (C) 2017 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "ScrollingTreeScrollingNodeDelegate.h"

#include <wtf/TZoneMallocInlines.h>

#if ENABLE(ASYNC_SCROLLING)

#include "ScrollingTreeScrollingNode.h"

namespace WebCore {

WTF_MAKE_TZONE_ALLOCATED_IMPL(ScrollingTreeScrollingNodeDelegate);

ScrollingTreeScrollingNodeDelegate::ScrollingTreeScrollingNodeDelegate(ScrollingTreeScrollingNode& scrollingNode)
    : m_scrollingNode(scrollingNode)
{
}

ScrollingTreeScrollingNodeDelegate::~ScrollingTreeScrollingNodeDelegate() = default;

RefPtr<ScrollingTree> ScrollingTreeScrollingNodeDelegate::scrollingTree() const
{
    return protectedScrollingNode()->scrollingTree();
}

FloatPoint ScrollingTreeScrollingNodeDelegate::lastCommittedScrollPosition() const
{
    return protectedScrollingNode()->lastCommittedScrollPosition();
}

FloatSize ScrollingTreeScrollingNodeDelegate::totalContentsSize()
{
    return protectedScrollingNode()->totalContentsSize();
}

FloatSize ScrollingTreeScrollingNodeDelegate::reachableContentsSize()
{
    return protectedScrollingNode()->reachableContentsSize();
}

IntPoint ScrollingTreeScrollingNodeDelegate::scrollOrigin() const
{
    return protectedScrollingNode()->scrollOrigin();
}

} // namespace WebCore

#endif // ENABLE(ASYNC_SCROLLING)

==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/WebCore/page/scrolling/ScrollingTreeScrollingNodeDelegate.cpp <==
/*
 * Copyright (C) 2017 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "ScrollingTreeScrollingNodeDelegate.h"

#include <wtf/TZoneMallocInlines.h>

#if ENABLE(ASYNC_SCROLLING)

#include "ScrollingTreeScrollingNode.h"

namespace WebCore {

WTF_MAKE_TZONE_ALLOCATED_IMPL(ScrollingTreeScrollingNodeDelegate);

ScrollingTreeScrollingNodeDelegate::ScrollingTreeScrollingNodeDelegate(ScrollingTreeScrollingNode& scrollingNode)
    : m_scrollingNode(scrollingNode)
{
}

ScrollingTreeScrollingNodeDelegate::~ScrollingTreeScrollingNodeDelegate() = default;

RefPtr<ScrollingTree> ScrollingTreeScrollingNodeDelegate::scrollingTree() const
{
    return scrollingNode()->scrollingTree();
}

FloatPoint ScrollingTreeScrollingNodeDelegate::lastCommittedScrollPosition() const
{
    return scrollingNode()->lastCommittedScrollPosition();
}

FloatSize ScrollingTreeScrollingNodeDelegate::totalContentsSize()
{
    return scrollingNode()->totalContentsSize();
}

FloatSize ScrollingTreeScrollingNodeDelegate::reachableContentsSize()
{
    return scrollingNode()->reachableContentsSize();
}

IntPoint ScrollingTreeScrollingNodeDelegate::scrollOrigin() const
{
    return scrollingNode()->scrollOrigin();
}

} // namespace WebCore

#endif // ENABLE(ASYNC_SCROLLING)
